Module complete

Module complete 

Structs

CompleteOptions
Options for generating shell completion scripts.

Functions

complete
Generates a shell completion script for the specified shell.
complete_init
Generates a shell-specific “init” script that enables tab-completion for any command on $PATH whose first line is a usage shebang, without requiring per-script usage g completion generation. The user sources this once from their shell rc.