pub fn effective_exit_codes_ref<'a>(
spec: &Spec,
path: impl IntoIterator<Item = &'a SpecCommand>,
) -> Vec<SpecExitCode>Expand description
Reference-based form used by tree walkers that already hold the command chain.
pub fn effective_exit_codes_ref<'a>(
spec: &Spec,
path: impl IntoIterator<Item = &'a SpecCommand>,
) -> Vec<SpecExitCode>Reference-based form used by tree walkers that already hold the command chain.