pub fn effective_outputs_ref<'a>(
spec: &Spec,
path: impl IntoIterator<Item = &'a SpecCommand>,
) -> Vec<SpecOutput>Expand description
Reference-based form used by tree walkers that already hold the command chain.
pub fn effective_outputs_ref<'a>(
spec: &Spec,
path: impl IntoIterator<Item = &'a SpecCommand>,
) -> Vec<SpecOutput>Reference-based form used by tree walkers that already hold the command chain.