pub fn effective_select(spec: &Spec, path: &[SpecCommand]) -> Option<String>Expand description
The value-taking selector in effect for a command, if it reaches that command.
pub fn effective_select(spec: &Spec, path: &[SpecCommand]) -> Option<String>The value-taking selector in effect for a command, if it reaches that command.