pub fn effective_select_ref(
spec: &Spec,
path: &[&SpecCommand],
) -> Option<String>Expand description
Reference-based form used by tree walkers that already hold the command chain.
pub fn effective_select_ref(
spec: &Spec,
path: &[&SpecCommand],
) -> Option<String>Reference-based form used by tree walkers that already hold the command chain.