Structs
- Complete
Options - Options for generating shell completion scripts.
Functions
- complete
- Generates a shell completion script for the specified shell.
- complete_
init - Generates a shell-specific “init” script that enables tab-completion for any
command on
$PATHwhose first line is ausageshebang, without requiring per-scriptusage g completiongeneration. The user sources this once from their shell rc.