#[non_exhaustive]pub struct Spec {Show 21 fields
pub name: String,
pub bin: String,
pub cmd: SpecCommand,
pub config: SpecConfig,
pub version: Option<String>,
pub usage: String,
pub complete: IndexMap<String, SpecComplete>,
pub source_code_link_template: Option<String>,
pub author: Option<String>,
pub about: Option<String>,
pub about_long: Option<String>,
pub about_md: Option<String>,
pub license: Option<String>,
pub before_help: Option<String>,
pub after_help: Option<String>,
pub before_help_long: Option<String>,
pub after_help_long: Option<String>,
pub disable_help: Option<bool>,
pub min_usage_version: Option<String>,
pub examples: Vec<SpecExample>,
pub default_subcommand: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Stringbin: Stringcmd: SpecCommandconfig: SpecConfigversion: Option<String>usage: Stringcomplete: IndexMap<String, SpecComplete>source_code_link_template: Option<String>about: Option<String>about_long: Option<String>about_md: Option<String>license: Option<String>before_help: Option<String>after_help: Option<String>before_help_long: Option<String>after_help_long: Option<String>disable_help: Option<bool>min_usage_version: Option<String>examples: Vec<SpecExample>default_subcommand: Option<String>Default subcommand to use when first non-flag argument is not a known subcommand.
This enables “naked” command syntax like mise foo instead of mise run foo.
Implementations
Sourceimpl Spec
impl Spec
Sourcepub fn parse_file(file: &Path) -> Result<Spec, UsageErr>
pub fn parse_file(file: &Path) -> Result<Spec, UsageErr>
Parse a spec from a file.
Automatically detects whether the file is:
- A
.kdlor.usage.kdlfile containing a raw spec - A script file with embedded
# USAGE:comments
If bin is not specified in the spec, it defaults to the filename.
Sourcepub fn parse_script(file: &Path) -> Result<Spec, UsageErr>
pub fn parse_script(file: &Path) -> Result<Spec, UsageErr>
Parse a spec from a script file’s embedded USAGE comments.
Extracts the spec from comment lines starting with # USAGE: or // USAGE:.
If bin is not specified in the spec, it defaults to the filename.
pub fn parse_spec(input: &str) -> Result<Spec, UsageErr>
👎Deprecated
pub fn is_empty(&self) -> bool
pub fn merge(&mut self, other: Spec)